@@ -5,68 +5,66 @@ use warnings;
 use LWP::UserAgent;
 use URI;
 use URI::Escape;
-use JSON::Any;
+use JSON::MaybeXS;
 use Carp;
 
-use constant ACCESS_TOKEN_URL => 'https://graph.facebook.com/oauth/access_token';
-use constant AUTHORIZE_URL => 'https://www.facebook.com/dialog/oauth';
+use constant ACCESS_TOKEN_URL => 'https://graph.facebook.com/v2.2/oauth/access_token';
+use constant AUTHORIZE_URL    => 'https://www.facebook.com/v2.2/dialog/oauth';
 
-our $VERSION = '0.07';
+our $VERSION = '0.09';
 
 sub new {
     my ($class,%options) = @_;
     my $self = {};
     $self->{options} = \%options;
-    
+
     if (!$options{access_token}){
-        croak "Yuo must provide your application id when construct new method\n Net::Facebook::Oauth2->new( application_id => '...' )" unless defined $self->{options}->{application_id};
-        croak "Yuo must provide your application secret when construct new method\n Net::Facebook::Oauth2->new( application_secret => '...' )" unless defined $self->{options}->{application_secret};
+        croak "You must provide your application id in new()\nNet::Facebook::Oauth2->new( application_id => '...' )" unless defined $self->{options}->{application_id};
+        croak "You must provide your application secret in new()\nNet::Facebook::Oauth2->new( application_secret => '...' )" unless defined $self->{options}->{application_secret};
     }
-    
+
     $self->{browser}          = $options{browser} || LWP::UserAgent->new;
     $self->{access_token_url} = $options{access_token_url} || ACCESS_TOKEN_URL;
     $self->{authorize_url}    = $options{authorize_url} || AUTHORIZE_URL;
     $self->{access_token}     = $options{access_token};
     $self->{display}          = $options{display} || 'page'; ##other values popup and wab
-    
+
     return bless($self, $class);
 }
 
 sub get_authorization_url {
-    
     my ($self,%params) = @_;
-    
+
     $params{callback} ||= $self->{options}->{callback};
     croak "You must pass a callback parameter with Oauth v2.0" unless defined $params{callback};
-    
+
     $params{display} = $self->{display} unless defined $params{display};
     $self->{options}->{callback} = $params{callback};
-    
+
     my $scope = join(",", @{$params{scope}}) if defined($params{scope});
-    
+
     my $url = $self->{authorize_url}
     ."?client_id="
     .uri_escape($self->{options}->{application_id})
     ."&redirect_uri="
     .uri_escape($params{callback});
-    
+
     $url .= "&scope=$scope" if $scope;
     $url .= "&display=".$params{display};
-    
+
     return $url;
 }
 
 
 sub get_access_token {
-    
     my ($self,%params) = @_;
     $params{callback} ||= $self->{options}->{callback};
     $params{code} ||= $self->{options}->{code};
-    
+
     croak "You must pass a code parameter with Oauth v2.0" unless defined $params{code};
     croak "You must pass callback URL" unless defined $params{callback};
     $self->{options}->{code} = $params{code};
-    
+
     ###generating access token URL
     my $getURL = $self->{access_token_url}
     ."?client_id="
@@ -76,28 +74,27 @@ sub get_access_token {
     ."&client_secret="
     .uri_escape($self->{options}->{application_secret})
     ."&code=$params{code}";
-    
+
     my $response = $self->{browser}->get($getURL);
-    
+
     ##got an error response from facebook
     ##die and display error message
     if (!$response->is_success){
-        my $j = JSON::Any->new;
-        my $error = $j->jsonToObj($response->content());
+        my $error = decode_json($response->content());
         croak "'" .$error->{error}->{type}. "'" . " " .$error->{error}->{message};
     }
-    
+
     ##everything is ok proccess response and extract access token
     my $file = $response->content();
     my ($access_token,$expires) = split(/&/, $file);
     my ($string,$token) = split(/=/, $access_token);
-    
+
     ###save access token
     if ($token){
         $self->{access_token} = $token;
         return $token;
     }
-    
+
     croak "can't get access token";
 }
 
@@ -105,12 +102,13 @@ sub get {
     my ($self,$url,$params) = @_;
     unless ($self->_has_access_token($url)) {
         croak "You must pass access_token" unless defined $self->{access_token};
-        $url .= "?access_token=" . $self->{access_token};
-    }    
-    
+        $url .= $self->{_has_query} ? '&' : '?';
+        $url .= "access_token=" . $self->{access_token};
+    }
+
     ##construct the new url
     my @array;
-    
+
     while ( my ($key, $value) = each(%{$params})){
         $value = uri_escape($value);
         push(@array, "$key=$value");
@@ -118,7 +116,7 @@ sub get {
 
     my $string = join('&', @array);
     $url .= "&".$string if $string;
-    
+
     my $response = $self->{browser}->get($url);
     my $content = $response->content();
     return $self->_content($content);
@@ -148,8 +146,7 @@ sub delete {
 
 sub as_hash {
     my ($self) = @_;
-    my $j = JSON::Any->new;
-    return $j->jsonToObj($self->{content});
+    return decode_json($self->{content});
 }
 
 sub as_json {
@@ -167,6 +164,8 @@ sub _has_access_token {
     my ($self, $url) = @_;
     my $uri = URI->new($url);
     my %q = $uri->query_form;
+    #also check if we have a query and save result
+    $self->{_has_query} = $uri->query();
     if (grep { $_ eq 'access_token' } keys %q) {
         return 1;
     }
@@ -174,58 +173,59 @@ sub _has_access_token {
 }
 
 1;
-
+__END__
 =head1 NAME
 
 Net::Facebook::Oauth2 - a simple Perl wrapper around Facebook OAuth v2.0 protocol
 
+=for html
+<a href="https://travis-ci.org/mamod/Net-Facebook-Oauth2"><img src="https://travis-ci.org/mamod/Net-Facebook-Oauth2.svg?branch=master"></a>
+
 =head1 SYNOPSIS
 
-    use CGI;
-    my $cgi = CGI->new;
-    
+Somewhere in your application's login process:
+
     use Net::Facebook::Oauth2;
-    
+
     my $fb = Net::Facebook::Oauth2->new(
-        application_id => 'your_application_id', 
+        application_id     => 'your_application_id', 
         application_secret => 'your_application_secret',
-        callback => 'http://yourdomain.com/facebook/callback'
+        callback           => 'http://yourdomain.com/facebook/callback'
     );
-    
-    ###get authorization URL for your application
+
+    # get the authorization URL for your application
     my $url = $fb->get_authorization_url(
-        scope => ['offline_access','publish_stream'],
+        scope   => [ 'public_profile', 'email', 'offline_access', 'publish_stream' ],
         display => 'page'
     );
-    
-    ####now redirect to this url
-    print $cgi->redirect($url);
-    
-    ##once user authorizes your application facebook will send him/her back to your application
-    ##to the callback link provided above
-    
-    ###in your callback block capture verifier code and get access_token
-    
-    my $fb = Net::Facebook::Oauth2->new(
-        application_id => 'your_application_id',
-        application_secret => 'your_application_secret',
-        callback => 'http://yourdomain.com/facebook/callback'
-    );
-    
-    my $access_token = $fb->get_access_token(code => $cgi->param('code'));
-    ###save this token in database or session
-    
-    ##later on your application you can use this verifier code to comunicate
-    ##with facebook on behalf of this user
-    
+
+Now redirect the user to this C<$url>.
+
+Once the user authorizes your application, Facebook will send him/her back
+to your application, on the C<callback> link provided above.
+
+Inside that callback route, use the verifier code parameter that Facebook
+sends to get the access token:
+
+    # param() below is a bogus function. Use whatever your web framework
+    # provides (e.g. $c->req->param('code'), $cgi->param('code'), etc)
+    my $code = param('code');
+
+    my $access_token = $fb->get_access_token(code => $code);
+
+If you got so far, your user is logged! Save this access token in your
+database or session.
+
+Later on you can use it to communicate with Facebook on behalf of this user:
+
     my $fb = Net::Facebook::Oauth2->new(
         access_token => $access_token
     );
-    
+
     my $info = $fb->get(
-        'https://graph.facebook.com/me' ##Facebook API URL
+        'https://graph.facebook.com/v2.2/me'   # Facebook API URL
     );
-    
+
     print $info->as_json;
 
 =head1 DESCRIPTION
@@ -280,6 +280,9 @@ you can get more information about scope/Extended Permission from
 
 L<http://developers.facebook.com/docs/authentication/permissions>
 
+Please note that requesting information other than C<public_profile>,
+C<email> and C<user_friends> B<will require your app to be reviewed by Facebook!>
+
 =item * C<callback>
 
 callback URL, where facebook will send users after they authorize
@@ -388,9 +391,25 @@ L<http://developers.facebook.com/docs/api>
 
 Mahmoud A. Mehyar, E<lt>mamod.mehyar@gmail.comE<gt>
 
+=head1 CONTRIBUTORS
+
+Big Thanks To
+
+=over 4
+
+=item * Takatsugu Shigeta L<@comewalk|https://github.com/comewalk>
+
+=item * Breno G. de Oliveira L<@garu|https://github.com/garu>
+
+=item * squinker L<@squinker|https://github.com/squinker>
+
+=item * Valcho Nedelchev L<@valchonedelchev|https://github.com/valchonedelchev>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2013 by Mahmoud A. Mehyar
+Copyright (C) 2012-2015 by Mahmoud A. Mehyar
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.1 or,
